package com.game.business.service;

import java.util.List;

import com.game.business.domain.AppGameLottery;
import com.game.business.domain.AppGameLotteryHistory;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 游戏开奖记录（备份）Service接口
 *
 * @author game
 * @date 2025-01-09
 */
public interface IAppGameLotteryHistoryService extends IService<AppGameLotteryHistory> {
    /**
     * 查询游戏开奖记录（备份）
     *
     * @param id 游戏开奖记录（备份）主键
     * @return 游戏开奖记录（备份）
     */
    public AppGameLotteryHistory selectAppGameLotteryHistoryById(Long id);

    /**
     * 查询游戏开奖记录（备份）列表
     *
     * @param appGameLotteryHistory 游戏开奖记录（备份）
     * @return 游戏开奖记录（备份）集合
     */
    public List<AppGameLotteryHistory> selectAppGameLotteryHistoryList(AppGameLotteryHistory appGameLotteryHistory);

    /**
     * 新增游戏开奖记录（备份）
     *
     * @param appGameLotteryHistory 游戏开奖记录（备份）
     * @return 结果
     */
    public int insertAppGameLotteryHistory(AppGameLotteryHistory appGameLotteryHistory);

    /**
     * 修改游戏开奖记录（备份）
     *
     * @param appGameLotteryHistory 游戏开奖记录（备份）
     * @return 结果
     */
    public int updateAppGameLotteryHistory(AppGameLotteryHistory appGameLotteryHistory);

    /**
     * 批量删除游戏开奖记录（备份）
     *
     * @param ids 需要删除的游戏开奖记录（备份）主键集合
     * @return 结果
     */
    public int deleteAppGameLotteryHistoryByIds(Long[] ids);

    /**
     * 删除游戏开奖记录（备份）信息
     *
     * @param id 游戏开奖记录（备份）主键
     * @return 结果
     */
    public int deleteAppGameLotteryHistoryById(Long id);

    AppGameLotteryHistory selectLottery(Long classId, Long gameId, String gameDate);
}